==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "Search:"
: "Търси:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Намерени апликации {0} - {1} of {2}"

, "No applications to display"
: "Няма намерени апликации"

, "Order"
: "Последователност"

, "Name"
: "Име"

, "Status"
: "Статус"

, "Version"
: "Версия"

, "Confirm"
: "Потвърждение"

, "Do you really want to delete the selected groups?"
: "Наистина ли желаете да изтриете селектираните групи?"

, "Deleting group(s)..."
: "Изтрива група(и)..."

, "Failed"
: "Неуспех"

, "Some error occurred while trying to delete the group."
: "Настъпила е грешка при опит за изтриване на групата."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Намерени групи {0} - {1} от {2}"

, "No groups to display"
: "Няма намерени групи"

, "ID"
: "ID (идентификационен номер)"

, "E-mail"
: ""

, "Description"
: "Описание"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Грешки"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""
 ,""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: "Име на компютьра"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "Моля изчакайте"

, "Updating Tag"
: "Актуализира таг..."

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Моля коригирайте грешките."

, "Allowed Contexts"
: "Позволен Контекст"

, "Context"
: "Контекст"

, "Account Rights"
: "Права на конто"

, "View"
: "Преглед"

, "Use"
: "Употреба"

, "Tag Name"
: "Име на таг"

, "Color"
: "Цвят"

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: "Добавя нов таг"

, "Edit Tag \"{0}\""
: "Обработи таг \"{0}\""

, "Do you really want to delete the selected tags?"
: "Наистина ли желаете да изтриете селектираните категории?"

, "Deleting tag(s)..."
: "Изтрива категория(-и)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Намерени категории {0} - {1} от {2}"

, "No tags to display"
: "Няма намерени категории"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "Актуализира членство"

, "Could not save role."
: "Неуспешно запаметяване на роля."

, "Deleting role..."
: "Изтрива роля..."

, "Some error occurred while trying to delete the role."
: "Настъпила е грешка при опит за изтриване на ролята."

, "Rights"
: "Права"

, "Members"
: "Членове"

, "Role Name"
: "Име на роля"

, "Role"
: ""

, "Add New Role"
: "Добави нова роля"

, "Edit Role \"{0}\""
: "Редактира роля \"{0}\""

, "Do you really want to delete the selected roles?"
: "Наистина ли желаете да изтриете селектираните роли?"

, "Deleting role(s)..."
: "Изтрива роля(-и)."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Показва роли {0} - {1} от {2}"

, "No roles to display"
: "Няма намерени роли"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Groups"
: "Групи"

, "Applications"
: "Апликации"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "Основна група"

, "Unix"
: ""

, "Home Directory"
: "Home-Директория"

, "Login Shell"
: "Login Shell"

, "Windows"
: ""

, "Home Drive"
: "Home-Твърд диск"

, "Login Time"
: "Време на влизане"

, "never logged in"
: "До този момент няма регистрирано влизане."

, "Home Path"
: "Home-Адрес"

, "Logout Time"
: "Време на излизане"

, "never logged off"
: "До този момент няма регистрирано излизане."

, "Profile Path"
: "Адрес на профила"

, "Password Last Set"
: "Последно зададена парола"

, "never"
: "никога"

, "Logon Script"
: "Скрирт за влизане"

, "Password Can Change"
: "Паролата може де бъде сменена"

, "not set"
: "не е създаден"

, "Password Must Change"
: "Паролата трябва де бъде сменена"

, "Kick Off Time"
: "Време на излизане"

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: "Потребител"

, "First name"
: "Име"

, "Last name"
: "Фамилия"

, "Login name"
: ""

, "Password"
: "Парола"

, "OpenID"
: ""

, "enabled"
: "активиран"

, "disabled"
: "деактивиран"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Краен срок"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: "Последно регистрирано влизане"

, "don't know"
: "неизвестен"

, "Last login from"
: "Последното регистрирано влизане е от"

, "Password set"
: "Задава парола"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Файлов сървър"

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  "Потребител"
 ,"Потребители"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba Потребител"
 ,"Samba Потребители"

]
, "Email User, Email Users"
: [
  ""
 ,""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Паролата е сменена"

, "Set new password"
: "Създаване на нова рарола"

, "Please enter the new password:"
: "Моля вкарайте новата парола:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Име на група"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Членове на група"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Комрютър"
 ,"Комрютъра"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Правомощия за достъп"

, "Containers"
: ""

, "Shared Tags"
: "Общи категории"

, "Customfields"
: ""

, "Computers"
: "Комрютри"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Администратор"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP Адрес"

, "Client Type"
: ""

, "Session ID"
: "ID на сесия"

, "Login Name"
: "Потребителско име"

, "Result"
: "Резултат"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "грешна парола"

, "ambiguous username"
: "неопределено потребителско име"

, "user not found"
: "такъв потребител не е намерен"

, "failure"
: "неуспех"

, "success"
: "успех"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

































, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Потребител"

, "Samba User"
: "Samba Потребител"

, "Email User"
: ""

, "Container"
: ""

, "Computer"
: "Комрютър"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Admin/js/Admin-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  ""
 ,""

]
, "User, Users"
: [
  "Потребител"
 ,"Потребители"

]
, "Groups"
: "Групи"

, "Roles"
: "Правомощия за достъп"

, "Applications"
: "Апликации"

, "Containers"
: ""

, "Shared Tags"
: "Общи категории"

, "Customfields"
: ""

, "Computers"
: "Комрютри"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Log"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Администратор"

, "Refresh"
: ""

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Computer Name"
: "Име на компютьра"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Описание"

, "Name"
: "Име"

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Име на група"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Членове на група"

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Confirm"
: "Потвърждение"

, "Do you really want to delete the selected tags?"
: "Наистина ли желаете да изтриете селектираните категории?"

, "Deleting tag(s)..."
: "Изтрива категория(-и)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Search:"
: "Търси:"

, "Displaying tags {0} - {1} of {2}"
: "Намерени категории {0} - {1} от {2}"

, "No tags to display"
: "Няма намерени категории"

, "ID"
: "ID (идентификационен номер)"

, "Color"
: "Цвят"

, "Usage:&#160;"
: ""

, "Do you really want to delete the selected roles?"
: "Наистина ли желаете да изтриете селектираните роли?"

, "Deleting role(s)..."
: "Изтрива роля(-и)."

, "Failed"
: "Неуспех"

, "Some error occurred while trying to delete the role."
: "Настъпила е грешка при опит за изтриване на ролята."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Показва роли {0} - {1} от {2}"

, "No roles to display"
: "Няма намерени роли"

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Order"
: "Последователност"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Наистина ли желаете да изтриете селектираните групи?"

, "Deleting group(s)..."
: "Изтрива група(и)..."

, "Some error occurred while trying to delete the group."
: "Настъпила е грешка при опит за изтриване на групата."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Намерени групи {0} - {1} от {2}"

, "No groups to display"
: "Няма намерени групи"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP Адрес"

, "Login Time"
: "Време на влизане"

, "Logout Time"
: "Време на излизане"

, "Client Type"
: ""

, "Session ID"
: "ID на сесия"

, "Login Name"
: "Потребителско име"

, "Result"
: "Резултат"

, "User Agent"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "грешна парола"

, "ambiguous username"
: "неопределено потребителско име"

, "user not found"
: "такъв потребител не е намерен"

, "failure"
: "неуспех"

, "success"
: "успех"

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Грешки"

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Status"
: "Статус"

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Фамилия"

, "First name"
: "Име"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: "Последно регистрирано влизане"

, "Last login from"
: "Последното регистрирано влизане е от"

, "Password Must Change"
: "Паролата трябва де бъде сменена"

, "Password changed"
: "Паролата е сменена"

, "Expires"
: "Краен срок"

, "Set new password"
: "Създаване на нова рарола"

, "Please enter the new password:"
: "Моля вкарайте новата парола:"

, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba Потребител"
 ,"Samba Потребители"

]
, "Email User, Email Users"
: [
  ""
 ,""

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "Основна група"

, "Unix"
: ""

, "Home Directory"
: "Home-Директория"

, "Login Shell"
: "Login Shell"

, "Windows"
: ""

, "Home Drive"
: "Home-Твърд диск"

, "never logged in"
: "До този момент няма регистрирано влизане."

, "Home Path"
: "Home-Адрес"

, "never logged off"
: "До този момент няма регистрирано излизане."

, "Profile Path"
: "Адрес на профила"

, "Password Last Set"
: "Последно зададена парола"

, "never"
: "никога"

, "Logon Script"
: "Скрирт за влизане"

, "Password Can Change"
: "Паролата може де бъде сменена"

, "not set"
: "не е създаден"

, "Kick Off Time"
: "Време на излизане"

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Forward Only"
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: "Потребител"

, "Password"
: "Парола"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "активиран"

, "disabled"
: "деактивиран"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "неизвестен"

, "Password set"
: "Задава парола"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Файлов сървър"

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Computer, Computers"
: [
  "Комрютър"
 ,"Комрютъра"

]
, "Please wait"
: "Моля изчакайте"

, "Updating Memberships"
: "Актуализира членство"

, "Could not save role."
: "Неуспешно запаметяване на роля."

, "Please fix the errors noted."
: "Моля коригирайте грешките."

, "Deleting role..."
: "Изтрива роля..."

, "Rights"
: "Права"

, "Members"
: "Членове"

, "Role Name"
: "Име на роля"

, "Transferring {0}..."
: ""

, "Role"
: ""

, "Add New Role"
: "Добави нова роля"

, "Edit Role \"{0}\""
: "Редактира роля \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Актуализира таг..."

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Позволен Контекст"

, "Context"
: "Контекст"

, "Account Rights"
: "Права на конто"

, "View"
: "Преглед"

, "Use"
: "Употреба"

, "Tag Name"
: "Име на таг"

, "Tag"
: ""

, "Add New Tag"
: "Добавя нов таг"

, "Edit Tag \"{0}\""
: "Обработи таг \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Намерени апликации {0} - {1} of {2}"

, "No applications to display"
: "Няма намерени апликации"

, "Version"
: "Версия"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""






























, "ImportExportDefinition"
: ""

, "Application"
: ""

, "User"
: "Потребител"

, "Access Log"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Group"
: ""

, "Samba User"
: "Samba Потребител"

, "Email User"
: ""

, "Computer"
: "Комрютър"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
